#include <avr/io.h>

#include "adc.h"
#include "defs.h"

/* The ATmega32 ADC (analog-to digital converter) is discussed starting on page
   201 of the ATmega32 data sheet. */

void adc_init(void)
{
	/* Enable the analog-to-digital converter. See the ATmega32 data sheet,
	   page 216. */
	ADCSRA |= _BV(ADEN);
	/* Prescale the ADC clock by 128. See the ATmega32 data sheet, page
	   217. */
	ADCSRA |= _BV(ADPS2) | _BV(ADPS1) | _BV(ADPS0);
	/* Bits REFS1 and REFS0 of ADMUX specify the reference voltage. REFS1 =
	   0, REFS0 = 1 uses AVCC. See the ATmega32 data sheet, page 214. */
	ADMUX &= ~_BV(REFS1);
	ADMUX |= _BV(REFS0);
}

unsigned short adc_read_channel(unsigned char channel)
{
	/* Select the channel (in the low 5 bits of ADMUX). */
	ADMUX = (ADMUX & ~0x1F) | (channel & 0x07);
	/* Set the ADC Start Conversion bit. */
	ADCSRA |= _BV(ADSC);

	/* The ADIF bit is set when the conversion is complete. */
	loop_until_bit_is_set(ADCSRA, ADIF);

	/* Return the contents of the analog-to-digital register. */
	return ADC;
}
