#ifndef _DEFS_H
#define _DEFS_H

#include <avr/io.h>

/* The CPU frequency (8 MHz). */
#define F_CPU 8000000UL

/* If SAMPLE_RATE_THROTTLE is defined, then the sample rate will be limited by
   SAMPLE_FREQUENCY and SAMPLE_PERIOD. */
/*
#define USE_SAMPLE_RATE_THROTTLE
*/

/* If USE_PARANOID_WRITE is defined, the program will look for the first
   all-zero sector before recording data. */
/*
*/
#define USE_PARANOID_WRITE

/*
*/
#define USE_GPS

/* The time to wait before deploying (actually unlatching), in seconds. */
#define DEPLOYMENT_TIME (2 * 60 * 60)

/* The time it takes to unlatch, in seconds. */
#define UNLATCH_DURATION (30)

/* How long it takes to deploy, in seconds. */
#define DEPLOYMENT_DURATION 1

/* The amount of time between pictures, in seconds. This has to be large enough
   that the camera turns itself off in between pictures. */
#define CAMERA_TIME (5 * 60)

/* The maximum number of pictures to take. */
#define MAX_NUM_PICTURES 15

/* The parameter controlling how quickly the exponential weighted average of
   acceleration. Values near 0 are smoother but slower to react, while values
   near 1 are jerky but quick to react. */
#define AVG_ACC_RESPONSE 0.05
/* How close the current acceleration must be to the average acceleration on
   each axis for each time step to be considered quiescent. */
#define QUIESCENCE_THRESHOLD 4
/* How long the craft must be quiescent before being allowed to deploy, in
   seconds. */
#define QUIESCENCE_TIMER (10 * 60)

/* The sample frequency in hertz. The program will not sample more frequently
   than this. This has an effect only when USE_SAMPLE_RATE_THROTTLE is
   defined. */
#define SAMPLE_FREQUENCY 100
/* The sample period in milliseconds. */
#define SAMPLE_PERIOD (1000 / SAMPLE_FREQUENCY)

#define NUM_CONFIRMATION_FLASHES 5
#define NUM_CONFIRMATION_SECTORS 12

#define LATCH_PORT PORTC
#define LATCH_DDR DDRC
#define LATCH PC2

#define CAMERA_PORT PORTC
#define CAMERA_DDR DDRC
#define CAMERA_POWER PC0
#define CAMERA_SHUTTER PC1

#define SERVO_DDR DDRB
#define SERVO PB3

#define MMC_PORT PORTB
#define MMC_DDR DDRB
#define MMC0_CS PB1
#define MMC1_CS PB2

#define LED_PORT PORTB
#define LED_DDR DDRB
#define LED PB0

#define CHANNEL_X_ANG_VEL 7
#define CHANNEL_Y_ANG_VEL 6
#define CHANNEL_Z_ANG_VEL 5
#define CHANNEL_X_ACC 2
#define CHANNEL_Y_ACC 3
#define CHANNEL_Z_ACC 4
#define CHANNEL_PRESSURE 0
#define CHANNEL_TEMP_EXT 1

#endif
