#include "defs.h"
#include "serial.h"

#define NMEA_MAX_LENGTH 80

void gps_init(void)
{
	/* Perhaps set Baud rate to 4800 here? Or put GPS module into NMEA
	   mode? */
}

/* Read an NMEA sentence from the USART. Return the sentence as a terminated
   string in a static buffer. If no sentence is available, return NULL.
   serial_init must be called before using this function. */
const char *gps_read_sentence(void)
{
	static char read_buffer[NMEA_MAX_LENGTH];
	static int read_index = 0;
	char c;

start:
	if (read_index == 0) {
		/* Look for the beginning '$'. */
		do {
			if (serial_read(&c, 1) == 0)
				return NULL;
		} while (c != '$');
		read_buffer[read_index++] = c;
	}

	for (;;) {
		if (serial_read(&c, 1) == 0)
			return NULL;
		if (read_buffer[read_index - 1] == '\r' && c == '\n') {
			/* We got the "\r\n". Ignore the '\r' that's already in
			   the buffer and exit the loop. */
			read_index--;
			break;
		}
		if (read_index < NMEA_MAX_LENGTH) {
			read_buffer[read_index++] = c;
		} else {
			/* Too long. Ignore this sentence and try again. */
			read_index = 0;
			goto start;
		}
	}

	read_buffer[read_index] = '\0';

	/* Get ready for the next sentence. */
	read_index = 0;

	return read_buffer;
}
